﻿using System;
using System.Windows.Forms;
using DotNetBrowser;
using DotNetBrowser.WinForms;

namespace TabbedProxySample
{
    public class ProxyTabPage : TabPage
    {
        private ProxyConfig proxyConfig;
        private string contextDirectory;

        private BrowserContext context;
        private Browser browser;
        private WinFormsBrowserView browserView;

        public ProxyTabPage(ProxyConfig proxyConfig)
        {
            this.proxyConfig = proxyConfig;

            //Generate unique context directory name
            contextDirectory = Guid.NewGuid().ToString("N");

            Text = proxyConfig != null ? proxyConfig.ToString() : "Direct access";

            InitializeBrowser();
        }

        public void GoToUrl(string url)
        {
            browser.LoadURL(url);
        }

        private void InitializeBrowser()
        {
            BrowserContextParams contextParams = new BrowserContextParams(contextDirectory);
            //The BrowserContext should be stored in RAM
            contextParams.StorageType = StorageType.MEMORY;

            //For non-default proxy settings
            if (proxyConfig != null)
            {
                //Setup the proxy rules
                contextParams.ProxyConfig =
                    new CustomProxyConfig(string.Format("http={0};https={0};socks={0}", proxyConfig.ToString()));
            }

            context = new BrowserContext(contextParams);

            //Check if the proxy server requires authentication
            if (proxyConfig != null && proxyConfig.IsAuthRequired)
            {
                //Create the network delegate and assign it to the context
                context.NetworkService.NetworkDelegate =
                    new ProxyNetworkDelegate(proxyConfig.Username, proxyConfig.Password);
            }

            browser = BrowserFactory.Create(context);
            browserView = new WinFormsBrowserView(browser) { Dock = DockStyle.Fill };
            Controls.Add(browserView);
        }

        public void DisposeBrowser()
        {
            browserView.Dispose();
            browser.Dispose();
            context.Dispose();
        }
    }
}
